# coding: utf-8

"""
Earnix import export API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field
from typing_extensions import Annotated, Self

from earnix_elevate.clients.imx.models.bucket_file_details_response import (
    BucketFileDetailsResponse,
)
from earnix_elevate.clients.imx.models.bucket_folder_details_response import (
    BucketFolderDetailsResponse,
)
from earnix_elevate.clients.imx.models.bucket_object_metadata_response import (
    BucketObjectMetadataResponse,
)


class BrowseBucketDataSourceResponse(BaseModel):
    """
    BrowseBucketDataSourceResponse
    """  # noqa: E501

    folders: Optional[
        Annotated[List[BucketFolderDetailsResponse], Field(max_length=1000)]
    ] = None
    files: Optional[
        Annotated[List[BucketFileDetailsResponse], Field(max_length=1000)]
    ] = None
    metadata: Optional[BucketObjectMetadataResponse] = None
    __properties: ClassVar[List[str]] = ["folders", "files", "metadata"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of BrowseBucketDataSourceResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in folders (list)
        _items = []
        if self.folders:
            for _item_folders in self.folders:
                if _item_folders:
                    _items.append(_item_folders.to_dict())
            _dict["folders"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in files (list)
        _items = []
        if self.files:
            for _item_files in self.files:
                if _item_files:
                    _items.append(_item_files.to_dict())
            _dict["files"] = _items
        # override the default output from pydantic by calling `to_dict()` of metadata
        if self.metadata:
            _dict["metadata"] = self.metadata.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of BrowseBucketDataSourceResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "folders": [
                    BucketFolderDetailsResponse.from_dict(_item)
                    for _item in obj["folders"]
                ]
                if obj.get("folders") is not None
                else None,
                "files": [
                    BucketFileDetailsResponse.from_dict(_item) for _item in obj["files"]
                ]
                if obj.get("files") is not None
                else None,
                "metadata": BucketObjectMetadataResponse.from_dict(obj["metadata"])
                if obj.get("metadata") is not None
                else None,
            }
        )
        return _obj



from abc import ABC
from os import getenv
from typing import Any, Optional

from .auth import AuthClient
from .const import SERVER_TPL, USER_AGENT


class BaseElevateClient(ABC):
    _route: str
    _conf_class: Any

    @property
    def auth(self) -> AuthClient:
        return self._auth

    @auth.setter
    def auth(self, auth_client: AuthClient) -> None:
        self._auth = auth_client

    def __init__(self, server: str, *args: Any, **kwargs: Any) -> None:
        base_url = SERVER_TPL.format(server) + self._route
        kwargs["configuration"] = self._conf_class(host=base_url)
        super().__init__(*args, **kwargs)
        self.user_agent = USER_AGENT


class BaseElevateService(ABC):
    _client_class: Any

    @staticmethod
    def _arg_env_err(value: Optional[str], env_key: str) -> str:
        if value:
            return value
        env_value = getenv(env_key)
        if env_value:
            return env_value
        raise LookupError(f"Missing {env_key}.")

    def __init__(
        self,
        server: Optional[str] = None,
        client_id: Optional[str] = None,
        secret_key: Optional[str] = None,
    ) -> None:
        """
        :param server: The base URL of the Elevate service API. If not provided, defaults to the `E2_SERVER` environment variable.
        :type server: str, optional
        :param client_id: The client ID for authentication. If not provided, defaults to the `E2_CLIENT_ID` environment variable.
        :type client_id: str, optional
        :param secret_key: The secret key for authentication. If not provided, defaults to the `E2_SECRET_KEY` environment variable.
        :type secret_key: str, optional
        """
        _server = self._arg_env_err(server, "E2_SERVER")
        _client_id = self._arg_env_err(client_id, "E2_CLIENT_ID")
        _secret_key = self._arg_env_err(secret_key, "E2_SECRET_KEY")

        self.api_client = self._client_class(_server)
        self.api_client.auth = AuthClient(self, _server, _client_id, _secret_key)



# coding: utf-8

"""
Earnix DataService API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing_extensions import Self


class DataSetNodeProperties(BaseModel):
    """
    DataSetNodeProperties
    """  # noqa: E501

    node_type: Optional[StrictStr] = Field(default=None, alias="nodeType")
    data_set_id: Optional[StrictInt] = Field(default=None, alias="dataSetId")
    __properties: ClassVar[List[str]] = ["nodeType", "dataSetId"]

    @field_validator("node_type")
    def node_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(["TABLE", "RECIPE"]):
            raise ValueError("must be one of enum values ('TABLE', 'RECIPE')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DataSetNodeProperties from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DataSetNodeProperties from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {"nodeType": obj.get("nodeType"), "dataSetId": obj.get("dataSetId")}
        )
        return _obj



from ..clients.data import ApiClient, Configuration, DataTableServiceApi
from .common import BaseElevateClient, BaseElevateService


class DataClient(BaseElevateClient, ApiClient):
    _route = "/api/data"
    _conf_class = Configuration


class DataTableService(BaseElevateService, DataTableServiceApi):
    _client_class = DataClient
